//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************

//---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---//

#ifndef GRSAnalysisManager_h
#define GRSAnalysisManager_h 1

#include "G4Run.hh"
#include "G4RunManager.hh"
#include "GRSTrackingAction.hh"
#include "GRSDetectorConstruction.hh"
#include "G4SystemOfUnits.hh"
#include "G4UnitsTable.hh"
#include "G4AnalysisManager.hh"
#include "g4hntools_defs.hh"
#include "globals.hh"

//---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---//

class GRSAnalysisManager
{
  public:
   GRSAnalysisManager(GRSDetectorConstruction *det);
  ~GRSAnalysisManager();

  void Book();
  void Save();

  void FillSrcNtuple(G4double sourceEnergy, G4double sourcePosX, G4double sourcePosY, G4double sourcePosZ);

  void FillEdepNtuple(G4double edep);

  void PrintStatistic(const G4Run* theRun, G4double totalEfficiency, G4double peakEfficiency);

  void CreateASCIIDataFile(const G4Run* theRun, G4double totalEfficiency, G4double peakEfficiency);

  private:
  G4bool fFactoryOn;
  GRSDetectorConstruction* fDetector;
};

#endif

//---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---//

