// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************

//---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---//

#ifndef GRSDetectorConstruction_H
#define GRSDetectorConstruction_H 1

#include "globals.hh"
#include "G4Element.hh"
#include "G4Isotope.hh"
#include "G4Material.hh"
#include "G4NistManager.hh"
#include "G4MaterialTable.hh"
#include "G4SDManager.hh"
#include "G4StateManager.hh"
#include "G4RunManager.hh"
#include "G4GeometryManager.hh"
#include "G4UImanager.hh"
#include "G4Box.hh"
#include "G4Tubs.hh"
#include "G4Sphere.hh"
#include "G4Cons.hh"
#include "G4VSolid.hh"
#include "G4RotationMatrix.hh"
#include "G4BooleanSolid.hh"
#include "G4SubtractionSolid.hh"
#include "G4IntersectionSolid.hh"
#include "G4UnionSolid.hh"
#include "G4DisplacedSolid.hh"
#include "G4SolidStore.hh"
#include "G4LogicalVolumeStore.hh"
#include "G4PhysicalVolumeStore.hh"
#include "G4LogicalVolume.hh"
#include "G4PVPlacement.hh"
#include "G4Colour.hh"
#include "G4VisAttributes.hh"
#include "G4ThreeVector.hh"
#include "G4UnitsTable.hh"
#include "G4SystemOfUnits.hh"
#include "G4PhysicalConstants.hh"
#include "G4VUserDetectorConstruction.hh"

#include "GRSDetectorMessenger.hh"

//---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---//

class G4Material;
class G4Element;
class GRSDetectorMessenger;

//---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---//

class GRSDetectorConstruction : public G4VUserDetectorConstruction
{
  public:

  GRSDetectorConstruction();
  ~GRSDetectorConstruction();

  G4VPhysicalVolume* Construct();

  void SetVerboseLevel(G4int value);
  G4int GetVerboseLevel(){return verbose;}

  void SetGeoIGermaniumDZLayer(G4double value);
  G4double GetGeoIGermaniumDZLayer(){return cristalDZLayer;}

  void AddGermaniumDeadZone(G4bool value);
  G4bool GetAddGermaniumDeadZone(){ return addGeDeadZone;}

  void AddShielding(G4bool value);
  G4bool GetAddShielding(){ return addShielding;}

  void SetGeoForceSolid(G4bool value);
  G4bool GetGeoForceSolid(){ return forceSolid;}

   void SetGeoSpaceAngle(G4double value);
  G4bool GetGeoSpaceAngle(){ return spaceAng;}

  void AddOutputFile(G4bool value);
  G4bool GetAddOutputFile(){ return addOutputFile;}

  void SetFileName(G4String value);
  G4String GetFileName(){ return fileName;}

  void SetNameOfParticle(G4String value);
  G4String GetNameOfParticle(){return particleName;}

  void SetAOfIon(G4int value);
  G4int GetAOfIon() { return ionA;}

  void SetZOfIon(G4int value);
  G4int GetZOfIon() { return ionZ;}

  void SetEnergyOfParticle(G4double value);
  G4double GetEnergyOfParticle(){return particleEnergy;}

  void SetDetectionEnergyThreshold(G4double value);
  G4double GetDetectionEnergyThreshold(){return detecEThreshold;}

   void SetPeakEnergySigma(G4double value);
  G4double GetPeakEnergySigma(){return energySigma;}

  void SetSourcePosition(G4ThreeVector value);
  G4ThreeVector GetSourcePosition(){return sourcePosition;}
  G4ThreeVector GetSourceTranslation(){return sourceTranslation;}

  void SetSourceType(G4String value);
  G4String GetSourceType(){return sourceType;}

  G4double GetVolumeSourceRadius(){return source_diameter/2;}
  G4double GetVolumeSourceHalfz(){return source_height/2;}

  private:

  G4bool updated, forceSolid, overlapChecking, addGeDeadZone, addShielding, addOutputFile;

  G4int verbose, ionA, ionZ;

  G4double source_diameter, source_height;

  G4double spaceAng, startAng;
  
  G4double cristalDZLayer;
  
  G4double particleEnergy, energySigma, detecEThreshold;
  
  G4String particleName, fileName, sourceType, cascadeFile;
  
  G4ThreeVector sourcePosition, sourceTranslation;
  
  G4VPhysicalVolume* ConstructDetector();
  G4LogicalVolume* shielding_1_log;
  G4LogicalVolume* shielding_2_log;

  GRSDetectorMessenger* detectorMessenger;

  void DefineMaterials();
  
  G4Material* Vacuum_mat;
  G4Material* Air_mat;
  G4Material* Lead_mat;
  G4Material* Aluminum_mat;
  G4Material* Germanium_mat;
  G4Material* Water_mat;
  G4Material* Dirt_mat;
  G4Material* Cellulose_mat;
};

//---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---//

#endif
