#!/bin/sh

# Script to analyze the output files of GRS simulation.
# Print FEP and TE efficiency values. 
# Plot efficiency values according to the energy.
#
# By C. Thiam, CEA, LNHB Saclay FR (cheick.thiam@cea.fr)

# clean output files
if [ -f "detectorAP_grs.out" ]; then rm detectorAP_grs.out; fi
if [ -f "detectorAS_grs.out" ]; then rm detectorAS_grs.out; fi
if [ -f "detectorAF_grs.out" ]; then rm detectorAF_grs.out; fi
if [ -f "detectorAW_grs.out" ]; then rm detectorAW_grs.out; fi
if [ -f "detectorBP_grs.out" ]; then rm detectorBP_grs.out; fi
if [ -f "detectorBS_grs.out" ]; then rm detectorBS_grs.out; fi
if [ -f "detectorBF_grs.out" ]; then rm detectorBF_grs.out; fi
if [ -f "detectorBW_grs.out" ]; then rm detectorBW_grs.out; fi

# parce detector A list
i=1
while read ligne 
do
if [ "$i" -lt 6 ]; then
FEP=`sed -n 16p $ligne`
TE=`sed -n 17p  $ligne`
echo $FEP $TE >> detectorAP_grs.out

elif [ "$i" -gt 5 -a "$i" -lt 11 ]; then 
FEP=`sed -n 16p $ligne`
TE=`sed -n 17p  $ligne`
echo $FEP $TE >> detectorAS_grs.out

elif [ "$i" -gt 10 -a "$i" -lt 16 ]; then 
FEP=`sed -n 16p $ligne`
TE=`sed -n 17p  $ligne`
echo $FEP $TE >> detectorAF_grs.out

elif [ "$i" -gt 15 ]; then
FEP=`sed -n 16p $ligne`
TE=`sed -n 17p  $ligne`
echo $FEP $TE >> detectorAW_grs.out
fi
i=$(($i+1))
done < detectorA.list

# parce detector B list
i=1
while read ligne 
do
if [ "$i" -lt 6 ]; then
FEP=`sed -n 16p $ligne`
TE=`sed -n 17p  $ligne`
echo $FEP $TE >> detectorBP_grs.out

elif [ "$i" -gt 5 -a "$i" -lt 11 ]; then
FEP=`sed -n 16p $ligne`
TE=`sed -n 17p  $ligne`
echo $FEP $TE >> detectorBS_grs.out

elif [ "$i" -gt 10 -a "$i" -lt 16 ]; then
FEP=`sed -n 16p $ligne`
TE=`sed -n 17p  $ligne`
echo $FEP $TE >> detectorBF_grs.out

elif [ "$i" -gt 15 ]; then
FEP=`sed -n 16p $ligne`
TE=`sed -n 17p  $ligne`
echo $FEP $TE >> detectorBW_grs.out
fi
i=$(($i+1))
done < detectorB.list

# print table of results 
echo "============================================================================================="
echo "                                         Detector A                                          "							
echo "============================================================================================="
echo "                                        Point source                                         "
echo "                                                                                             "
echo "        Full energy peak efficiency                        Total energy efficiency           "
echo "---------------------------------------------- ----------------------------------------------"
echo "E(kev)   Events    Counts    FEP      U(%)     E(kev)   Events    Counts    TE       U(%)    " 
cat detectorAP_grs.out
echo "---------------------------------------------------------------------------------------------"
echo "                                         Water source                                        "
echo "                                                                                             "
echo "        Full energy peak efficiency                        Total energy efficiency           "
echo "---------------------------------------------- ----------------------------------------------"
echo "                                                                                             "
echo "E(kev)   Events    Counts    FEP      U(%)     E(kev)   Events    Counts    TE       U(%)    " 
cat detectorAW_grs.out
echo "---------------------------------------------------------------------------------------------"
echo "                                         Filter source                                       "
echo "                                                                                             "
echo "        Full energy peak efficiency                        Total energy efficiency           "
echo "---------------------------------------------- ----------------------------------------------"
echo "E(kev)   Events    Counts    FEP      U(%)     E(kev)   Events    Counts    TE       U(%)    " 
cat detectorAF_grs.out
echo "---------------------------------------------------------------------------------------------"
echo "                                         Soil source                                         "
echo "                                                                                             "
echo "        Full energy peak efficiency                        Total energy efficiency           "
echo "---------------------------------------------- ----------------------------------------------"
echo "E(kev)   Events    Counts    FEP      U(%)     E(kev)   Events    Counts    TE       U(%)    " 
cat detectorAS_grs.out
echo "---------------------------------------------------------------------------------------------"
echo ""
echo "============================================================================================="
echo "                                         Detector B                                          "                                                    
echo "============================================================================================="
echo "                                        Point source                                         "
echo "                                                                                             "
echo "        Full energy peak efficiency                        Total energy efficiency           "
echo "---------------------------------------------- ----------------------------------------------"
echo "E(kev)   Events    Counts    FEP      U(%)     E(kev)   Events    Counts    TE       U(%)    " 
cat detectorBP_grs.out
echo "---------------------------------------------------------------------------------------------"
echo "                                        Water source                                         "
echo "                                                                                             "
echo "        Full energy peak efficiency                        Total energy efficiency           "
echo "---------------------------------------------- ----------------------------------------------"
echo "E(kev)   Events    Counts    FEP      U(%)     E(kev)   Events    Counts    TE       U(%)    " 
cat detectorBW_grs.out
echo "---------------------------------------------------------------------------------------------"
echo "                                        Filter source                                        "
echo "                                                                                             "
echo "        Full energy peak efficiency                        Total energy efficiency           "
echo "---------------------------------------------- ----------------------------------------------"
echo "E(kev)   Events    Counts    FEP      U(%)     E(kev)   Events    Counts    TE       U(%)    " 
cat detectorBF_grs.out
echo "---------------------------------------------------------------------------------------------"
echo "                                        Soil source                                          "
echo "                                                                                             "
echo "        Full energy peak efficiency                        Total energy efficiency           "
echo "---------------------------------------------- ----------------------------------------------"
echo "E(kev)   Events    Counts    FEP      U(%)     E(kev)   Events    Counts    TE       U(%)    " 
cat detectorBS_grs.out
echo "---------------------------------------------------------------------------------------------"
echo ""

# create simple graph with gnuplot 
minE=0
maxE=1050
gnuplot -persist <<-EOFMarker
set multiplot layout 2, 2 title "GammaRaySpec results" font "14"
set style line 1 lc rgb 'red'    lt 1 lw 2 pt 5  ps 1.1  
set style line 2 lc rgb 'red'    lt 1 lw 2 pt 4  ps 1.1 
set style line 3 lc rgb 'green'  lt 1 lw 2 pt 7  ps 1.2 
set style line 4 lc rgb 'green'  lt 1 lw 2 pt 6  ps 1.2 
set style line 5 lc rgb 'violet' lt 1 lw 2 pt 9  ps 1.2  
set style line 6 lc rgb 'violet' lt 1 lw 2 pt 8  ps 1.2 
set style line 7 lc rgb 'blue'   lt 1 lw 2 pt 13 ps 1.3 
set style line 8 lc rgb 'blue'   lt 1 lw 2 pt 12 ps 1.3 
set pointsize 2
set tmargin 2
set grid
set xrange [$minE:$maxE]
#set terminal wxt  enhanced title "Walt's steps " persist raise
#
set title "FEP detector A"
set xlabel "Energy (keV)"  
set ylabel "Full energy peak efficiency" 
plot "detectorAP_grs.out" using 1:4 with linespoints ls 1 title "AP", "detectorAS_grs.out" using 1:4 with linespoints ls 3 title "AS", "detectorAF_grs.out" using 1:4 with linespoints ls 5 title "AF", "detectorAW_grs.out" using 1:4 with linespoints ls 7 title "AW"
#
set title "FEP detector B"
set xlabel "Energy (keV)"
set ylabel "Full energy peak efficiency"
plot "detectorBP_grs.out" using 1:4 with linespoints ls 2 title "BP", "detectorBS_grs.out" using 1:4 with linespoints ls 4 title "BS", "detectorBF_grs.out" using 1:4 with linespoints ls 6 title "BF", "detectorBW_grs.out" using 1:4 with linespoints ls 8 title "BW"
#
set title "TE detector A"
set xlabel "Energy (keV)"
set ylabel "Total energy efficiency"
plot "detectorAP_grs.out" using 6:9 with linespoints ls 1 title "AP", "detectorAS_grs.out" using 6:9 with linespoints ls 3 title "AS", "detectorAF_grs.out" using 6:9 with linespoints ls 5 title "AF", "detectorAW_grs.out" using 6:9 with linespoints ls 7 title "AW"
#
set title "TE detector B"
set xlabel "Energy (keV)"
set ylabel "Total energy efficiency"
plot "detectorBP_grs.out" using 6:9 with linespoints ls 2 title "BP", "detectorBS_grs.out" using 6:9 with linespoints ls 4 title "BS", "detectorBF_grs.out" using 6:9 with linespoints ls 6 title "BF", "detectorBW_grs.out" using 6:9 with linespoints ls 8 title "BW"
EOFMarker
# rest of script, after gnuplot exits
# end
