//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
/// \file GammaRaySpectrometry/src/GRSActionInitialization.cc
/// \brief Implementation of the GRSActionInitialization class

//---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---//

#include "GRSActionInitialization.hh"

//---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---//

GRSActionInitialization::GRSActionInitialization(GRSDetectorConstruction* det, GRSPhysicsList*)
:G4VUserActionInitialization(), fDetector(det)
{}

//---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---//

GRSActionInitialization::~GRSActionInitialization()
{}

//---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---//

void GRSActionInitialization::BuildForMaster() const
{
  // histo manager
  GRSAnalysisManager*  histo = new GRSAnalysisManager(fDetector);
  
  // actions
  SetUserAction(new GRSRunAction(histo, fDetector));
}

//---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---//

void GRSActionInitialization::Build() const
{
  // histo manager
  GRSAnalysisManager*  histo = new GRSAnalysisManager(fDetector);
  
  // actions
  //
  SetUserAction(new GRSPrimaryGeneratorAction(fDetector));
  
  GRSRunAction* runAction = new GRSRunAction(histo, fDetector);
  SetUserAction(runAction);
  
  GRSEventAction* eventAction = new GRSEventAction(runAction, histo);
  SetUserAction(eventAction);

  GRSTrackingAction* trackAction = new GRSTrackingAction();
  SetUserAction(trackAction);

  GRSSteppingAction* steppingAction = new GRSSteppingAction(eventAction);
  SetUserAction(steppingAction);
}  

//---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---//

G4VSteppingVerbose* GRSActionInitialization::InitializeSteppingVerbose() const
{
 return new GRSSteppingVerbose();
}

//---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---//
