//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
/// \file GammaRaySpectrometry/src/GRSEventAction.cc
/// \brief Implementation of the GRSEventAction class

//---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---//

#include "GRSEventAction.hh"

//---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---//

GRSEventAction::GRSEventAction(GRSRunAction* run, GRSAnalysisManager* histo)
:G4UserEventAction(), fRunAction(run), fAnalysisManager(histo), fEdep(0.)
{}

//---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---//

GRSEventAction::~GRSEventAction()
{}

//---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---//

void GRSEventAction::BeginOfEventAction(const G4Event*)
{  
    // initialization per event
    fEdep = 0.;
}

//---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---//

void GRSEventAction::EndOfEventAction(const G4Event*)
{
    //send edep in RunAction
    //
    fRunAction->FillPerEvent(fEdep);

    // fill ntuple id=0
    fAnalysisManager->FillSrcNtuple((((GRSTrackingAction*)(G4RunManager::GetRunManager()->GetUserTrackingAction()))->GetLastPrimaryEnergy()), 
                                    ((((GRSTrackingAction*)(G4RunManager::GetRunManager()->GetUserTrackingAction()))->GetLastPrimaryParticlePosition()).x()), 
                                    ((((GRSTrackingAction*)(G4RunManager::GetRunManager()->GetUserTrackingAction()))->GetLastPrimaryParticlePosition()).y()),
                                    ((((GRSTrackingAction*)(G4RunManager::GetRunManager()->GetUserTrackingAction()))->GetLastPrimaryParticlePosition()).z()) );
    // fill ntuple id=1
    fAnalysisManager->FillEdepNtuple(fEdep);
}  

//---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---//
