//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
// \file GammaRaySpectrometry/src/GRSPhysicsListMessenger.cc
// \brief Implementation of the PhysicsListMessenger class

//---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---//

#include "GRSPhysicsListMessenger.hh"

//---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---//

GRSPhysicsListMessenger::GRSPhysicsListMessenger(GRSPhysicsList* pPhys)
:pPhysicsList(pPhys)
{
  physDir = new G4UIdirectory("/GRS/physics/");
  physDir->SetGuidance("GRS physics list control commands.");
            
  pListCmd = new G4UIcmdWithAString("/GRS/physics/addPhysics",this);  
  pListCmd->SetGuidance("Add modula physics list.");
  pListCmd->SetGuidance("Candidates               : emstandard emlivermore emlowenergy empenelope standard livermore lowenergy penelope");
  pListCmd->SetGuidance("emstandard  or standard  : standard EM physics with current 'best' options setting these options are explicited in PhysListEmStandard");
  pListCmd->SetGuidance("emlowenergy or lowenergy : low-energy EM physics implementing experimental low-energy models");
  pListCmd->SetGuidance("emlivermore or livermore : low-energy EM physics using Livermore data");
  pListCmd->SetGuidance("empenelope  or penelope  : low-energy EM physics implementing Penelope models");
  pListCmd->SetParameterName("PList",false);
  pListCmd->SetCandidates("emstandard emlivermore emlowenergy empenelope standard livermore lowenergy penelope");
  pListCmd->AvailableForStates(G4State_PreInit);  
 
  gammaCutCmd = new G4UIcmdWithADoubleAndUnit("/GRS/physics/GammaCut",this);  
  gammaCutCmd->SetGuidance("Set gamma cut.");
  gammaCutCmd->SetParameterName("Gcut",false);
  gammaCutCmd->SetUnitCategory("Length");
  gammaCutCmd->SetRange("Gcut>0.0");
  gammaCutCmd->AvailableForStates(G4State_PreInit,G4State_Idle);

  electCutCmd = new G4UIcmdWithADoubleAndUnit("/GRS/physics/ElectronCut",this);  
  electCutCmd->SetGuidance("Set electron cut.");
  electCutCmd->SetParameterName("Ecut",false);
  electCutCmd->SetUnitCategory("Length");
  electCutCmd->SetRange("Ecut>0.0");
  electCutCmd->AvailableForStates(G4State_PreInit,G4State_Idle);
  
  protoCutCmd = new G4UIcmdWithADoubleAndUnit("/GRS/physics/PositronCut",this);  
  protoCutCmd->SetGuidance("Set positron cut.");
  protoCutCmd->SetParameterName("Pcut",false);
  protoCutCmd->SetUnitCategory("Length");
  protoCutCmd->SetRange("Pcut>0.0");
  protoCutCmd->AvailableForStates(G4State_PreInit,G4State_Idle);  

  allCutCmd = new G4UIcmdWithADoubleAndUnit("/GRS/physics/Cuts",this);  
  allCutCmd->SetGuidance("Set cut for all.");
  allCutCmd->SetParameterName("cut",false);
  allCutCmd->SetUnitCategory("Length");
  allCutCmd->SetRange("cut>0.0");
  allCutCmd->AvailableForStates(G4State_PreInit,G4State_Idle);  
}

//---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---//

GRSPhysicsListMessenger::~GRSPhysicsListMessenger()
{
  delete gammaCutCmd;
  delete electCutCmd;
  delete protoCutCmd;
  delete allCutCmd;
  delete pListCmd;
  delete physDir;    
}

//---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---//

void GRSPhysicsListMessenger::SetNewValue(G4UIcommand* command, G4String newValue)
{ 
  if( command == pListCmd ) 
   { pPhysicsList->AddPhysicsList(newValue);}
  
  if( command == gammaCutCmd )
   { pPhysicsList->SetCutForGamma(gammaCutCmd->GetNewDoubleValue(newValue));}
     
  if( command == electCutCmd )
   { pPhysicsList->SetCutForElectron(electCutCmd->GetNewDoubleValue(newValue));}
     
  if( command == protoCutCmd )
   { pPhysicsList->SetCutForPositron(protoCutCmd->GetNewDoubleValue(newValue));}

  if( command == allCutCmd )
  {
   G4double cut = allCutCmd->GetNewDoubleValue(newValue);
   pPhysicsList->SetCutForGamma(cut);
   pPhysicsList->SetCutForElectron(cut);
   pPhysicsList->SetCutForPositron(cut);
  }
 }

//---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---//

