//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
/// \file GammaRaySpectrometry/src/GRSSteppingAction.cc
/// \brief Implementation of the GRSSteppingAction class

//---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---//

#include "GRSSteppingAction.hh"

//---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---//

GRSSteppingAction::GRSSteppingAction(GRSEventAction* evt): G4UserSteppingAction(), fEventAction(evt)
{}

//---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---//

GRSSteppingAction::~GRSSteppingAction()
{}

//---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---//

void GRSSteppingAction::UserSteppingAction(const G4Step* aStep)
{
  if(aStep->GetPreStepPoint()->GetTouchableHandle()->GetVolume()->GetName() !="HPGe_CRISTAL_SD") return; // Sensitive detector

  // get edep in step and send on eventAction class
  G4double edep = aStep->GetTotalEnergyDeposit();
  fEventAction->AddEdep(edep);
}

//---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---Gamma-Ray-Spectrometry---%%%---//

